package com.diagbot.facade;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.diagbot.dto.DoctorAverageLevelDTO;
import com.diagbot.dto.DoctorAverageStatisticsDTO;
import com.diagbot.dto.GetDetailRecordListPageDTO;
import com.diagbot.dto.GetDoctorDetailPageDTO;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.util.DateUtil;
import com.diagbot.util.SysUserUtils;
import com.diagbot.vo.DoctorAverageLevelVO;
import com.diagbot.vo.DoctorAverageStatisticsVO;
import com.diagbot.vo.GetDetailRecordListPageVO;
import com.diagbot.vo.GetDoctorDetailPageVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @Description:控制台（医生）统计相关处理
 * @Author:songxl
 * @date 2022/4/8 13:20
 */
@Component
public class ConsoleByDoctorFacade {
    @Autowired
    private BehospitalInfoFacade behospitalInfoFacade;

    @Autowired
    QcresultInfoFacade qcresultInfoFacade;


    /**
     * 医生质控平均分页面统计
     *
     * @param doctorAverageStatisticsVO
     * @Return com.baomidou.mybatisplus.core.metadata.IPage<com.diagbot.dto.DoctorAverageStatisticsDTO>
     */
    public IPage<DoctorAverageStatisticsDTO> doctorAverageStatistics(DoctorAverageStatisticsVO doctorAverageStatisticsVO) {
        doctorAverageStatisticsVO.setHospitalId(SysUserUtils.getCurrentHospitalID());
        return behospitalInfoFacade.getBaseMapper().doctorAverageStatistics(doctorAverageStatisticsVO);
    }

    /**
     * 医生质控平均分-患者列表（等级）
     *
     * @param doctorAverageLevelVO
     * @Return com.baomidou.mybatisplus.core.metadata.IPage<com.diagbot.dto.DoctorAverageLevelDTO>
     */
    public IPage<DoctorAverageLevelDTO> doctorAverageLevelPage(DoctorAverageLevelVO doctorAverageLevelVO) {
        doctorAverageLevelPageSet(doctorAverageLevelVO);
        return behospitalInfoFacade.getBaseMapper().doctorAverageLevelPage(doctorAverageLevelVO);
    }

    private void doctorAverageLevelPageSet(DoctorAverageLevelVO doctorAverageLevelVO) {
        //入参验证
        //入院时间
        if (null != doctorAverageLevelVO && null != doctorAverageLevelVO.getBehosDateStart()) {
            doctorAverageLevelVO.setBehosDateStart(DateUtil.getFirstTimeOfDay(doctorAverageLevelVO.getBehosDateStart()));
        }
        if (null != doctorAverageLevelVO && null != doctorAverageLevelVO.getBehosDateEnd()) {
            doctorAverageLevelVO.setBehosDateEnd(DateUtil.getFirstTimeOfDay(DateUtil.addDay(doctorAverageLevelVO.getBehosDateEnd(), 1)));
        }
        if (null != doctorAverageLevelVO && null != doctorAverageLevelVO.getBehosDateStart() && null != doctorAverageLevelVO.getBehosDateEnd()) {
            if (DateUtil.after(doctorAverageLevelVO.getBehosDateStart(), doctorAverageLevelVO.getBehosDateEnd())) {
                throw new CommonException(CommonErrorCode.PARAM_IS_ERROR, "入院时间的开始时间必须小于结束时间！");
            }
        }
        //出院时间
        if (null != doctorAverageLevelVO && null != doctorAverageLevelVO.getLeaveHosDateStart()) {
            doctorAverageLevelVO.setLeaveHosDateStart(DateUtil.getFirstTimeOfDay(doctorAverageLevelVO.getLeaveHosDateStart()));
        }
        if (null != doctorAverageLevelVO && null != doctorAverageLevelVO.getLeaveHosDateEnd()) {
            doctorAverageLevelVO.setLeaveHosDateEnd(DateUtil.getFirstTimeOfDay(DateUtil.addDay(doctorAverageLevelVO.getLeaveHosDateEnd(), 1)));
        }
        if (null != doctorAverageLevelVO && null != doctorAverageLevelVO.getLeaveHosDateStart() && null != doctorAverageLevelVO.getLeaveHosDateEnd()) {
            if (DateUtil.after(doctorAverageLevelVO.getLeaveHosDateStart(), doctorAverageLevelVO.getLeaveHosDateEnd())) {
                throw new CommonException(CommonErrorCode.PARAM_IS_ERROR, "出院时间的开始时间必须小于结束时间！");
            }
        }
        doctorAverageLevelVO.setHospitalId(Long.parseLong(SysUserUtils.getCurrentHospitalID()));
    }

    /**
     * 获取缺陷列表
     *
     * @param getDoctorDetailPageVO
     * @return
     */
    public IPage<GetDoctorDetailPageDTO> getDoctorDetailPage(GetDoctorDetailPageVO getDoctorDetailPageVO) {
        IPage<GetDoctorDetailPageDTO> detailPageList = behospitalInfoFacade.getBaseMapper().getDoctorDetailPage(getDoctorDetailPageVO);
        return detailPageList;
    }

    /**
     * 获取缺陷数量对应的病历
     *
     * @param getDetailRecordListPageVO
     * @return
     */
    public IPage<GetDetailRecordListPageDTO> getDetailRecordListPage(GetDetailRecordListPageVO getDetailRecordListPageVO) {
        IPage<GetDetailRecordListPageDTO> detailPageList = behospitalInfoFacade.getBaseMapper().getDetailRecordListPage(getDetailRecordListPageVO);
        return detailPageList;
    }

}
